#include "event_demo.h"

#ifndef USE_DYNAMIC_CONNECT
// 静态链接
BEGIN_EVENT_TABLE(MainFrame, wxFrame)
EVT_MENU(wxID_ABOUT, MainFrame::OnAbout)
EVT_MENU(wxID_EXIT, MainFrame::OnQuit)

// EVT_SIZE事件映射宏不需要标识符参数因为这个事件只会被产生这个事件的控件所处理。
EVT_SIZE(MainFrame::OnSize)
/*
    这个例子表明，事件可以不必被产生这个事件的控件所处理。让我们假定这个按钮是MyFrame的子窗
    口。当按钮被点击的时候，wxWidgets会首先检查wxButton类是否指定了相应的处理函数，如果找不到，则在
    其父亲的类所属的事件表中进行查找，在这个例子中，按钮的父亲是MyFrame类型的一个实例，在其事件表中指
    明了一个对应的处理函数，因此MyFrame::OnButtonOK函数就被调用了。类似的搜索过程不光发生在窗口控件
    的父子继承树中，也发生在普通的类继承关系中，这意味着你可以选择在哪里定义事件的处理函数。举例来说，
    如果你设计了一个对话框，这个对话框需要响应的类似标识符为wxID_OK的command事件。但是你可能需要把
    这个控件的创建工作留给使用你的代码的其他的程序员，只要他在创建这个控件的时候使用同样的标识符，你仍
    然可以给这个控件为这个事件定义默认的处理函数。
*/
EVT_BUTTON(wxID_OK, MainFrame::OnButtonOK)
END_EVENT_TABLE()
#endif

bool MyApp::OnInit()
{
    MainFrame* frame = new MainFrame(wxT("Minimal wxWidgets App"));
    frame->Show(true);

#ifdef USE_DYNAMIC_CONNECT
/*
    三个参数分别为菜单标识符，事件标识符和事件处理函数指针。要注意这里的事件标
    识符 wxEVT_COMMAND_MENU_SELECTED不同于前面在静态事件表中用于表示事件映射的宏EVT_MENU,实
    际上EVT_MENU内部也使用了wxEVT_COMMAND_MENU_SELECTED.EVT_MENU其实也自动包含了用于对事
    件处理指针类型强制转换的宏 wxCommandEventHandler()。一般说来，如果事件处理函数的参数类型是
    wxXYZEvent,那么其处理函数的类型就应该用 wxXYZEventHandler宏进行强制转换.

    有对应的 frame->Disconnect
*/
    frame->Connect(wxID_EXIT, wxEVT_COMMAND_MENU_SELECTED,
                   wxCommandEventHandler(MainFrame::OnQuit));
    frame->Connect(wxID_ABOUT, wxEVT_COMMAND_MENU_SELECTED,
                   wxCommandEventHandler(MainFrame::OnAbout));
#endif
    return true;
}

void MainFrame::OnAbout(wxCommandEvent& event)
{
    wxString msg;
    msg.Printf(wxT("Hello and welcome to %s"), wxVERSION_STRING);
    wxMessageBox(msg, wxT("About Minimal"), wxOK | wxICON_INFORMATION, this);
}

void MainFrame::OnQuit(wxCommandEvent& event) { Close(); }

MainFrame::MainFrame(const wxString& title) : wxFrame(NULL, wxID_ANY, title)
{
    // 设置窗口图标
    // SetIcon(wxIcon(mondrian_xpm));
    // 创建菜单条
    wxMenu* fileMenu = new wxMenu;
    // 添加“关于”菜单项
    wxMenu* helpMenu = new wxMenu;
    helpMenu->Append(wxID_ABOUT, wxT("&About...\tF1"),
                     wxT("Show about dialog"));
    fileMenu->Append(wxID_EXIT, wxT("E&xit\tAlt-X"), wxT("Quit this program"));
    // 将菜单项添加到菜单条中
    wxMenuBar* menuBar = new wxMenuBar();
    menuBar->Append(fileMenu, wxT("&File"));
    menuBar->Append(helpMenu, wxT("&Help"));
    // ...然后将菜单条放置在主窗口上
    SetMenuBar(menuBar);

    wxButton* button =
        new wxButton(this, wxID_OK, wxT("OK"), wxPoint(200, 200));

    CreateStatusBar(2);
    SetStatusText(wxT("Welcome to wxWidgets!"));
}

void MainFrame::OnSize(wxSizeEvent& event) {}

void MainFrame::OnButtonOK(wxCommandEvent& event)
{
    /*
        当用户点击了确认按钮的时候，一个新的wxCommandEvent事件被创建，其中包
        含标识符wxID_OK和事件类型
       wxEVT_COMMAND_BUTTON_CLICKED，然后这个按钮的事件表开始通过
        wxEvtHandler::ProcessEvent函数进行匹配，事件表中的每一个条目都会去尝试匹配，然后是其父类wxControl
        的事件表，然后是wxWindow的。如果都没有匹配到，
       wxWidgets会搜索其父亲的类事件表，然后就找到了一
        条匹配条目：EVT_BUTTON(wxID_OK,MyFrame::OnButtonOK)

        简单来讲就是：先匹配自己的处理事件函数（若有继承往上找），没有去父类找。

        只有Command事件(其事件类型直接或者间接的继承自wxCommandEvent)才会被递归的应用
        到其父亲的事件表。通常这是wxWidgets的用户经常会感到困惑的地方，因此我们把那些不会传递给其父亲的事
        件表的事件列举如下：wxActivate, wxCloseEvent, wxEraseEvent,
       wxFocusEvent, wxKeyEvent, wxIdleEvent, wxInitDialogEvent,
       wxJoystickEvent, wxMenuEvent, wxMouseEvent, wxMoveEvent, wxPaintEvent,
        wxQueryLayoutInfoEvent, wxSizeEvent, wxScrollWinEvent,
       和wxSysColourChangedEvent，这些事件都不 会传给事件源控件的父亲.
        这些事件不会传递给其父亲，是因为这些事件仅对产生这个事件的窗口才有意义，举例来说，把一个子窗口的重
        绘事件发送给它的父亲，其实是没有任何意义的。

    */
}